@@ -31,15 +31,15 @@ dL0=c(log( c(rep(1,n1)/n,rep(1,n2)/n) ),0,0)
 
 if(var==FALSE){
   res=nlm(l.func,p=dL0,hessian=var)
-  c(beta_hat=res$estimate[n+1])
+  c(beta=res$estimate[n+1])
 }
 else{
   res=nlm(l.func,p=dL0,hessian=var)
-  beta_d=res$estimate[n+1]
+  Beta=res$estimate[n+1]
   SE=sqrt(solve(res$hessian)[n+1,n+1])
-  Z_d=beta_d/SE
-  P_d=1-pchisq(Z_d^2,df=1)
-  c(beta_hat=beta_d,SE=SE,Z=Z_d,P=P_d)
+  Z=Beta/SE
+  P=1-pchisq(Z^2,df=1)
+  c(beta=Beta,SE=SE,Z=Z,P=P)
 }
 
 }
